@@ -20,7 +20,7 @@ try:
 except ImportError:
     from yaml import Dumper, Loader
 
-__version__ = "0.0.12"
+__version__ = "0.0.13"
 
 COOKIECUTTER_URL = "https://github.com/anvilistas/amoni-cookiecutter.git"
 ANVIL_CONFIG_FILE = Path("app", "config.yaml")
@@ -115,7 +115,7 @@ def stop_services() -> None:
     docker.compose.down()
 
 
-def run_service(name: str) -> None:
+def run_service(name: str, remove: bool = True) -> None:
     """Run a given service
 
     Parameters
@@ -123,7 +123,7 @@ def run_service(name: str) -> None:
     name
         The name of the service to start
     """
-    docker.compose.run(name)
+    docker.compose.run(name, remove=remove)
 
 
 class AmoniRemoteCallbacks(pygit2.RemoteCallbacks):
